@@ -1,6 +1,8 @@
 use std::any::Any;
 use std::collections::HashMap;
 
+use dyn_clone::DynClone;
+
 use crate::expression::Expr;
 
 pub enum StatementKind {
@@ -13,11 +15,14 @@ pub enum StatementKind {
     OrderBy,
     GroupBy,
     AggregateFunction,
+    WindowFunction,
     GlobalVariable,
     Into,
 }
 
-pub trait Statement {
+dyn_clone::clone_trait_object!(Statement);
+
+pub trait Statement: DynClone {
     fn kind(&self) -> StatementKind;
     fn as_any(&self) -> &dyn Any;
 }
@@ -38,6 +43,7 @@ pub struct GQLQuery {
     pub hidden_selections: HashMap<String, Vec<String>>,
 }
 
+#[derive(Clone)]
 pub struct DoStatement {
     pub expression: Box<dyn Expr>,
 }
@@ -52,18 +58,20 @@ impl Statement for DoStatement {
     }
 }
 
+#[derive(Clone)]
 pub enum Distinct {
     None,
     DistinctAll,
     DistinctOn(Vec<String>),
 }
 
+#[derive(Clone)]
 pub struct TableSelection {
     pub table_name: String,
     pub columns_names: Vec<String>,
 }
 
-#[derive(PartialEq)]
+#[derive(Clone, PartialEq)]
 pub enum JoinKind {
     Cross,
     Inner,
@@ -72,19 +80,22 @@ pub enum JoinKind {
     Default,
 }
 
+#[derive(Clone)]
 pub enum JoinOperand {
     /// Used when JOIN is used first time on query, X JOIN Y,
     OuterAndInner(String, String),
-    /// Used for JOIN that used afrer first time, JOIN Z
+    /// Used for JOIN that used after first time, JOIN Z
     Inner(String),
 }
 
+#[derive(Clone)]
 pub struct Join {
     pub operand: JoinOperand,
     pub kind: JoinKind,
     pub predicate: Option<Box<dyn Expr>>,
 }
 
+#[derive(Clone)]
 pub struct SelectStatement {
     pub table_selections: Vec<TableSelection>,
     pub joins: Vec<Join>,
@@ -103,6 +114,7 @@ impl Statement for SelectStatement {
     }
 }
 
+#[derive(Clone)]
 pub struct WhereStatement {
     pub condition: Box<dyn Expr>,
 }
@@ -117,6 +129,7 @@ impl Statement for WhereStatement {
     }
 }
 
+#[derive(Clone)]
 pub struct HavingStatement {
     pub condition: Box<dyn Expr>,
 }
@@ -131,6 +144,7 @@ impl Statement for HavingStatement {
     }
 }
 
+#[derive(Clone)]
 pub struct LimitStatement {
     pub count: usize,
 }
@@ -145,6 +159,7 @@ impl Statement for LimitStatement {
     }
 }
 
+#[derive(Clone)]
 pub struct OffsetStatement {
     pub count: usize,
 }
@@ -159,15 +174,23 @@ impl Statement for OffsetStatement {
     }
 }
 
-#[derive(PartialEq)]
+#[derive(Clone, PartialEq)]
 pub enum SortingOrder {
     Ascending,
     Descending,
 }
 
+#[derive(Clone, PartialEq)]
+pub enum NullsOrderPolicy {
+    NullsFirst,
+    NullsLast,
+}
+
+#[derive(Clone)]
 pub struct OrderByStatement {
     pub arguments: Vec<Box<dyn Expr>>,
     pub sorting_orders: Vec<SortingOrder>,
+    pub nulls_order_policies: Vec<NullsOrderPolicy>,
 }
 
 impl Statement for OrderByStatement {
@@ -180,9 +203,10 @@ impl Statement for OrderByStatement {
     }
 }
 
+#[derive(Clone)]
 pub struct GroupByStatement {
     pub values: Vec<Box<dyn Expr>>,
-    pub has_with_rollup: bool,
+    pub has_with_roll_up: bool,
 }
 
 impl Statement for GroupByStatement {
@@ -195,11 +219,65 @@ impl Statement for GroupByStatement {
     }
 }
 
+#[derive(Clone)]
+pub struct WindowPartitioningClause {
+    pub expr: Box<dyn Expr>,
+}
+
+#[derive(Clone)]
+pub struct WindowOrderingClause {
+    pub order_by: OrderByStatement,
+}
+
+#[derive(Clone)]
+pub struct WindowDefinition {
+    pub name: Option<String>,
+    pub partitioning_clause: Option<WindowPartitioningClause>,
+    pub ordering_clause: Option<WindowOrderingClause>,
+}
+
+#[derive(Clone)]
+pub enum WindowFunctionKind {
+    AggregatedWindowFunction,
+    PureWindowFunction,
+}
+
+#[derive(Clone)]
+pub struct WindowFunction {
+    pub function_name: String,
+    pub arguments: Vec<Box<dyn Expr>>,
+    pub window_definition: WindowDefinition,
+    pub kind: WindowFunctionKind,
+}
+
+#[derive(Clone)]
+pub enum WindowValue {
+    Function(WindowFunction),
+    Expression(Box<dyn Expr>),
+}
+
+#[derive(Clone)]
+pub struct WindowFunctionsStatement {
+    pub window_values: HashMap<String, WindowValue>,
+}
+
+impl Statement for WindowFunctionsStatement {
+    fn as_any(&self) -> &dyn Any {
+        self
+    }
+
+    fn kind(&self) -> StatementKind {
+        StatementKind::WindowFunction
+    }
+}
+
+#[derive(Clone)]
 pub enum AggregateValue {
     Expression(Box<dyn Expr>),
     Function(String, Vec<Box<dyn Expr>>),
 }
 
+#[derive(Clone)]
 pub struct AggregationsStatement {
     pub aggregations: HashMap<String, AggregateValue>,
 }
@@ -214,6 +292,7 @@ impl Statement for AggregationsStatement {
     }
 }
 
+#[derive(Clone)]
 pub struct GlobalVariableStatement {
     pub name: String,
     pub value: Box<dyn Expr>,
@@ -229,6 +308,7 @@ impl Statement for GlobalVariableStatement {
     }
 }
 
+#[derive(Clone)]
 pub struct IntoStatement {
     pub file_path: String,
     pub lines_terminated: String,
