@@ -1,5 +1,4 @@
 pub mod array;
-pub mod base;
 pub mod boolean;
 pub mod composite;
 pub mod converters;
@@ -7,7 +6,11 @@ pub mod date;
 pub mod datetime;
 pub mod float;
 pub mod integer;
+pub mod interval;
 pub mod null;
 pub mod range;
 pub mod text;
 pub mod time;
+
+mod base;
+pub use base::Value;
