@@ -16,9 +16,11 @@ use gitql_ast::expression::Expr;
 use gitql_ast::expression::ExprKind::*;
 use gitql_ast::expression::GlobExpr;
 use gitql_ast::expression::GlobalVariableExpr;
+use gitql_ast::expression::GroupComparisonExpr;
 use gitql_ast::expression::GroupExpr;
 use gitql_ast::expression::InExpr;
 use gitql_ast::expression::IndexExpr;
+use gitql_ast::expression::IntervalExpr;
 use gitql_ast::expression::IsNullExpr;
 use gitql_ast::expression::LikeExpr;
 use gitql_ast::expression::LogicalExpr;
@@ -37,16 +39,15 @@ use gitql_ast::operator::ComparisonOperator;
 use gitql_ast::operator::PrefixUnaryOperator;
 use gitql_core::environment::Environment;
 use gitql_core::values::array::ArrayValue;
-use gitql_core::values::base::Value;
 use gitql_core::values::boolean::BoolValue;
 use gitql_core::values::composite::CompositeValue;
 use gitql_core::values::float::FloatValue;
 use gitql_core::values::integer::IntValue;
+use gitql_core::values::interval::IntervalValue;
 use gitql_core::values::null::NullValue;
 use gitql_core::values::text::TextValue;
+use gitql_core::values::Value;
 
-use regex::Regex;
-use regex::RegexBuilder;
 use std::cmp::Ordering;
 use std::string::String;
 
@@ -92,6 +93,10 @@ pub fn evaluate_expression(
             let expr = expression.as_any().downcast_ref::<BooleanExpr>().unwrap();
             evaluate_boolean(expr)
         }
+        Interval => {
+            let expr = expression.as_any().downcast_ref::<IntervalExpr>().unwrap();
+            evaluate_interval(expr)
+        }
         PrefixUnary => {
             let expr = expression.as_any().downcast_ref::<UnaryExpr>().unwrap();
             evaluate_prefix_unary(env, expr, titles, object)
@@ -118,6 +123,13 @@ pub fn evaluate_expression(
                 .unwrap();
             evaluate_comparison(env, expr, titles, object)
         }
+        GroupComparison => {
+            let expr = expression
+                .as_any()
+                .downcast_ref::<GroupComparisonExpr>()
+                .unwrap();
+            evaluate_group_comparison(env, expr, titles, object)
+        }
         Contains => {
             let expr = expression.as_any().downcast_ref::<ContainsExpr>().unwrap();
             evaluate_contains(env, expr, titles, object)
@@ -207,9 +219,7 @@ fn evaluate_assignment(
 }
 
 fn evaluate_string(expr: &StringExpr) -> Result<Box<dyn Value>, String> {
-    Ok(Box::new(TextValue {
-        value: expr.value.to_owned(),
-    }))
+    Ok(Box::new(TextValue::new(expr.value.to_owned())))
 }
 
 fn evaluate_symbol(
@@ -235,11 +245,7 @@ fn evaluate_array(
     for value in &expr.values {
         values.push(evaluate_expression(env, value, titles, object)?);
     }
-
-    Ok(Box::new(ArrayValue {
-        values,
-        base_type: expr.element_type.clone(),
-    }))
+    Ok(Box::new(ArrayValue::new(values, expr.element_type.clone())))
 }
 
 fn evaluate_global_variable(
@@ -259,14 +265,17 @@ fn evaluate_global_variable(
 
 fn evaluate_number(expr: &NumberExpr) -> Result<Box<dyn Value>, String> {
     Ok(match expr.value {
-        Number::Int(integer) => Box::new(IntValue { value: integer }),
-        Number::Float(float) => Box::new(FloatValue { value: float }),
+        Number::Int(integer) => Box::new(IntValue::new(integer)),
+        Number::Float(float) => Box::new(FloatValue::new(float)),
     })
 }
 
 fn evaluate_boolean(expr: &BooleanExpr) -> Result<Box<dyn Value>, String> {
-    let value = expr.is_true;
-    Ok(Box::new(BoolValue { value }))
+    Ok(Box::new(BoolValue::new(expr.is_true)))
+}
+
+fn evaluate_interval(expr: &IntervalExpr) -> Result<Box<dyn Value>, String> {
+    Ok(Box::new(IntervalValue::new(expr.interval.clone())))
 }
 
 fn evaluate_collection_index(
@@ -325,7 +334,6 @@ fn evaluate_arithmetic(
 ) -> Result<Box<dyn Value>, String> {
     let lhs = evaluate_expression(env, &expr.left, titles, object)?;
     let rhs = evaluate_expression(env, &expr.right, titles, object)?;
-
     match expr.operator {
         ArithmeticOperator::Plus => lhs.add_op(&rhs),
         ArithmeticOperator::Minus => lhs.sub_op(&rhs),
@@ -344,7 +352,6 @@ fn evaluate_comparison(
 ) -> Result<Box<dyn Value>, String> {
     let lhs = evaluate_expression(env, &expr.left, titles, object)?;
     let rhs = evaluate_expression(env, &expr.right, titles, object)?;
-
     match expr.operator {
         ComparisonOperator::Greater => lhs.gt_op(&rhs),
         ComparisonOperator::GreaterEqual => lhs.gte_op(&rhs),
@@ -356,6 +363,25 @@ fn evaluate_comparison(
     }
 }
 
+fn evaluate_group_comparison(
+    env: &mut Environment,
+    expr: &GroupComparisonExpr,
+    titles: &[String],
+    object: &Vec<Box<dyn Value>>,
+) -> Result<Box<dyn Value>, String> {
+    let lhs = evaluate_expression(env, &expr.left, titles, object)?;
+    let rhs = evaluate_expression(env, &expr.right, titles, object)?;
+    match expr.comparison_operator {
+        ComparisonOperator::Greater => lhs.group_gt_op(&rhs, &expr.group_operator),
+        ComparisonOperator::GreaterEqual => lhs.group_gte_op(&rhs, &expr.group_operator),
+        ComparisonOperator::Less => lhs.group_lt_op(&rhs, &expr.group_operator),
+        ComparisonOperator::LessEqual => lhs.group_lte_op(&rhs, &expr.group_operator),
+        ComparisonOperator::Equal => lhs.group_eq_op(&rhs, &expr.group_operator),
+        ComparisonOperator::NotEqual => lhs.group_bang_eq_op(&rhs, &expr.group_operator),
+        ComparisonOperator::NullSafeEqual => lhs.group_null_safe_eq_op(&rhs, &expr.group_operator),
+    }
+}
+
 fn evaluate_contains(
     env: &mut Environment,
     expr: &ContainsExpr,
@@ -384,34 +410,9 @@ fn evaluate_like(
     titles: &[String],
     object: &Vec<Box<dyn Value>>,
 ) -> Result<Box<dyn Value>, String> {
-    let pattern = evaluate_expression(env, &expr.pattern, titles, object)?;
     let input = evaluate_expression(env, &expr.input, titles, object)?;
-    if let Some(pattern_text) = pattern.as_any().downcast_ref::<TextValue>() {
-        if let Some(input_text) = input.as_any().downcast_ref::<TextValue>() {
-            let pattern = &format!(
-                "^{}$",
-                pattern_text
-                    .value
-                    .to_lowercase()
-                    .replace('%', ".*")
-                    .replace('_', ".")
-            );
-
-            let regex_result = RegexBuilder::new(pattern)
-                .multi_line(true)
-                .unicode(true)
-                .build();
-
-            if regex_result.is_err() {
-                return Err(regex_result.err().unwrap().to_string());
-            }
-            let regex = regex_result.ok().unwrap();
-            let is_match = regex.is_match(&input_text.value.to_lowercase());
-            return Ok(Box::new(BoolValue { value: is_match }));
-        }
-    }
-
-    Err("Invalid Arguments for LIKE expression".to_string())
+    let pattern = evaluate_expression(env, &expr.pattern, titles, object)?;
+    input.like_op(&pattern)
 }
 
 fn evaluate_regex(
@@ -420,34 +421,9 @@ fn evaluate_regex(
     titles: &[String],
     object: &Vec<Box<dyn Value>>,
 ) -> Result<Box<dyn Value>, String> {
-    let pattern = evaluate_expression(env, &expr.pattern, titles, object)?;
     let input = evaluate_expression(env, &expr.input, titles, object)?;
-    if let Some(pattern_text) = pattern.as_any().downcast_ref::<TextValue>() {
-        if let Some(input_text) = input.as_any().downcast_ref::<TextValue>() {
-            let pattern = &format!(
-                "^{}$",
-                pattern_text
-                    .value
-                    .to_lowercase()
-                    .replace('%', ".*")
-                    .replace('_', ".")
-            );
-
-            let regex_result = RegexBuilder::new(pattern)
-                .multi_line(true)
-                .unicode(true)
-                .build();
-
-            if regex_result.is_err() {
-                return Err(regex_result.err().unwrap().to_string());
-            }
-            let regex = regex_result.ok().unwrap();
-            let is_match = regex.is_match(&input_text.value.to_lowercase());
-            return Ok(Box::new(BoolValue { value: is_match }));
-        }
-    }
-
-    Err("Invalid Arguments for REGEX expression".to_string())
+    let pattern = evaluate_expression(env, &expr.pattern, titles, object)?;
+    input.regexp_op(&pattern)
 }
 
 fn evaluate_glob(
@@ -456,29 +432,9 @@ fn evaluate_glob(
     titles: &[String],
     object: &Vec<Box<dyn Value>>,
 ) -> Result<Box<dyn Value>, String> {
-    let rhs = evaluate_expression(env, &expr.pattern, titles, object)?;
-    if let Some(rhs_text) = rhs.as_any().downcast_ref::<TextValue>() {
-        let text = rhs_text.literal();
-        let pattern = &format!(
-            "^{}$",
-            text.replace('.', "\\.")
-                .replace('*', ".*")
-                .replace('?', ".")
-        );
-
-        let regex_result = Regex::new(pattern);
-        if regex_result.is_err() {
-            return Err(regex_result.err().unwrap().to_string());
-        }
-        let regex = regex_result.ok().unwrap();
-        let lhs = evaluate_expression(env, &expr.input, titles, object)?;
-        if let Some(lhs_text) = lhs.as_any().downcast_ref::<TextValue>() {
-            let is_match = regex.is_match(&lhs_text.value);
-            return Ok(Box::new(BoolValue { value: is_match }));
-        }
-    }
-
-    Err("Invalid Arguments for GLOB expression".to_string())
+    let input = evaluate_expression(env, &expr.input, titles, object)?;
+    let pattern = evaluate_expression(env, &expr.pattern, titles, object)?;
+    input.glob_op(&pattern)
 }
 
 fn evaluate_logical(
@@ -504,7 +460,6 @@ fn evaluate_bitwise(
 ) -> Result<Box<dyn Value>, String> {
     let lhs = evaluate_expression(env, &expr.left, titles, object)?;
     let rhs = evaluate_expression(env, &expr.right, titles, object)?;
-
     match expr.operator {
         BinaryBitwiseOperator::Or => lhs.or_op(&rhs),
         BinaryBitwiseOperator::And => lhs.and_op(&rhs),
@@ -525,7 +480,6 @@ fn evaluate_call(
     for arg in expr.arguments.iter() {
         arguments.push(evaluate_expression(env, arg, titles, object)?);
     }
-
     let function = env.std_function(function_name).unwrap();
     Ok(function(&arguments))
 }
@@ -542,8 +496,7 @@ fn evaluate_benchmark_call(
             evaluate_expression(env, &expr.expression, titles, object)?;
         }
     }
-
-    Ok(Box::new(IntValue { value: 0 }))
+    Ok(Box::new(IntValue::new_zero()))
 }
 
 fn evaluate_between(
@@ -573,9 +526,7 @@ fn evaluate_between(
                 && value.compare(&range_end).unwrap().is_le()
         }
     };
-    Ok(Box::new(BoolValue {
-        value: comparing_result,
-    }))
+    Ok(Box::new(BoolValue::new(comparing_result)))
 }
 
 fn evaluate_case(
@@ -609,19 +560,13 @@ fn evaluate_in(
     object: &Vec<Box<dyn Value>>,
 ) -> Result<Box<dyn Value>, String> {
     let argument = evaluate_expression(env, &expr.argument, titles, object)?;
-
     for value_expr in &expr.values {
         let value = evaluate_expression(env, value_expr, titles, object)?;
         if argument.equals(&value) {
-            return Ok(Box::new(BoolValue {
-                value: !expr.has_not_keyword,
-            }));
+            return Ok(Box::new(BoolValue::new(!expr.has_not_keyword)));
         }
     }
-
-    Ok(Box::new(BoolValue {
-        value: expr.has_not_keyword,
-    }))
+    Ok(Box::new(BoolValue::new(expr.has_not_keyword)))
 }
 
 fn evaluate_is_null(
@@ -632,9 +577,8 @@ fn evaluate_is_null(
 ) -> Result<Box<dyn Value>, String> {
     let argument = evaluate_expression(env, &expr.argument, titles, object)?;
     let is_null = argument.as_any().downcast_ref::<NullValue>().is_some();
-    Ok(Box::new(BoolValue {
-        value: if expr.has_not { !is_null } else { is_null },
-    }))
+    let result = if expr.has_not { !is_null } else { is_null };
+    Ok(Box::new(BoolValue::new(result)))
 }
 
 fn evaluate_cast(
