@@ -4,9 +4,9 @@ use gitql_ast::expression::CastExpr;
 use gitql_ast::expression::Expr;
 use gitql_ast::statement::TableSelection;
 use gitql_ast::types::any::AnyType;
-use gitql_ast::types::base::DataType;
 use gitql_ast::types::dynamic::DynamicType;
 use gitql_ast::types::varargs::VarargsType;
+use gitql_ast::types::DataType;
 use gitql_core::environment::Environment;
 
 use crate::diagnostic::Diagnostic;
@@ -73,7 +73,7 @@ pub fn check_function_call_arguments(
     if !has_varargs_parameter && arguments_count > parameters_count {
         return Err(Diagnostic::error(&format!(
             "Function `{}` expects `{}` arguments but got `{}`",
-            function_name, arguments_count, parameters_count
+            function_name, parameters_count, arguments_count
         ))
         .with_location(location)
         .as_boxed());
