@@ -6,9 +6,9 @@ use gitql_ast::types::integer::IntType;
 use gitql_ast::types::range::RangeType;
 use gitql_core::signature::Signature;
 use gitql_core::signature::StandardFunction;
-use gitql_core::values::base::Value;
 use gitql_core::values::boolean::BoolValue;
 use gitql_core::values::range::RangeValue;
+use gitql_core::values::Value;
 
 use std::collections::HashMap;
 
