@@ -288,71 +288,59 @@ pub fn register_std_text_function_signatures(map: &mut HashMap<&'static str, Sig
 
 pub fn text_bin(inputs: &[Box<dyn Value>]) -> Box<dyn Value> {
     let number = inputs[0].as_int().unwrap();
-    Box::new(TextValue {
-        value: format!("{number:b}"),
-    })
+    Box::new(TextValue::new(format!("{number:b}")))
 }
 
 pub fn text_lowercase(inputs: &[Box<dyn Value>]) -> Box<dyn Value> {
-    Box::new(TextValue {
-        value: inputs[0].as_text().unwrap().to_lowercase(),
-    })
+    Box::new(TextValue::new(inputs[0].as_text().unwrap().to_lowercase()))
 }
 
 pub fn text_uppercase(inputs: &[Box<dyn Value>]) -> Box<dyn Value> {
-    Box::new(TextValue {
-        value: inputs[0].as_text().unwrap().to_uppercase(),
-    })
+    Box::new(TextValue::new(inputs[0].as_text().unwrap().to_uppercase()))
 }
 
 pub fn text_reverse(inputs: &[Box<dyn Value>]) -> Box<dyn Value> {
-    Box::new(TextValue {
-        value: inputs[0]
+    Box::new(TextValue::new(
+        inputs[0]
             .as_text()
             .unwrap()
             .chars()
             .rev()
             .collect::<String>(),
-    })
+    ))
 }
 
 pub fn text_replicate(inputs: &[Box<dyn Value>]) -> Box<dyn Value> {
     let str = inputs[0].as_text().unwrap();
     let count = inputs[1].as_int().unwrap() as usize;
-    Box::new(TextValue {
-        value: str.repeat(count),
-    })
+    Box::new(TextValue::new(str.repeat(count)))
 }
 
 pub fn text_space(inputs: &[Box<dyn Value>]) -> Box<dyn Value> {
     let n = inputs[0].as_int().unwrap() as usize;
-    Box::new(TextValue {
-        value: " ".repeat(n),
-    })
+    Box::new(TextValue::new(" ".repeat(n)))
 }
 
 pub fn text_trim(inputs: &[Box<dyn Value>]) -> Box<dyn Value> {
-    Box::new(TextValue {
-        value: inputs[0].as_text().unwrap().trim().to_string(),
-    })
+    Box::new(TextValue::new(
+        inputs[0].as_text().unwrap().trim().to_string(),
+    ))
 }
 
 pub fn text_left_trim(inputs: &[Box<dyn Value>]) -> Box<dyn Value> {
-    Box::new(TextValue {
-        value: inputs[0].as_text().unwrap().trim_start().to_string(),
-    })
+    Box::new(TextValue::new(
+        inputs[0].as_text().unwrap().trim_start().to_string(),
+    ))
 }
 
 pub fn text_right_trim(inputs: &[Box<dyn Value>]) -> Box<dyn Value> {
-    Box::new(TextValue {
-        value: inputs[0].as_text().unwrap().trim_end().to_string(),
-    })
+    Box::new(TextValue::new(
+        inputs[0].as_text().unwrap().trim_end().to_string(),
+    ))
 }
 
 pub fn text_len(inputs: &[Box<dyn Value>]) -> Box<dyn Value> {
-    Box::new(IntValue {
-        value: inputs[0].as_text().unwrap().len() as i64,
-    })
+    Box::new(IntValue::new(inputs[0].as_text().unwrap().len() as i64))
 }
 
 pub fn text_ascii(inputs: &[Box<dyn Value>]) -> Box<dyn Value> {
@@ -362,21 +350,18 @@ pub fn text_ascii(inputs: &[Box<dyn Value>]) -> Box<dyn Value> {
     } else {
         text.chars().next().unwrap() as i64
     };
-
-    Box::new(IntValue { value })
+    Box::new(IntValue::new(value))
 }
 
 pub fn text_left(inputs: &[Box<dyn Value>]) -> Box<dyn Value> {
     let text = inputs[0].as_text().unwrap();
     if text.is_empty() {
-        return Box::new(TextValue {
-            value: "".to_string(),
-        });
+        return Box::new(TextValue::empty());
     }
 
     let number_of_chars = inputs[1].as_int().unwrap();
     if number_of_chars > text.len() as i64 {
-        return Box::new(TextValue { value: text });
+        return Box::new(TextValue::new(text));
     }
 
     let substring = text
@@ -393,25 +378,21 @@ pub fn text_datalength(inputs: &[Box<dyn Value>]) -> Box<dyn Value> {
 
 pub fn text_char(inputs: &[Box<dyn Value>]) -> Box<dyn Value> {
     let code = inputs[0].as_int().unwrap() as u32;
-    let value = if let Some(character) = char::from_u32(code) {
-        character.to_string()
+    if let Some(character) = char::from_u32(code) {
+        Box::new(TextValue::new(character.to_string()))
     } else {
-        "".to_string()
-    };
-    Box::new(TextValue { value })
+        Box::new(TextValue::empty())
+    }
 }
 
 pub fn text_charindex(inputs: &[Box<dyn Value>]) -> Box<dyn Value> {
     let substr = inputs[0].as_text().unwrap();
     let input = inputs[1].as_text().unwrap();
-
-    let value = if let Some(index) = input.to_lowercase().find(&substr.to_lowercase()) {
-        index as i64 + 1
+    if let Some(index) = input.to_lowercase().find(&substr.to_lowercase()) {
+        Box::new(IntValue::new(index as i64 + 1))
     } else {
-        0
-    };
-
-    Box::new(IntValue { value })
+        Box::new(IntValue::new_zero())
+    }
 }
 
 pub fn text_replace(inputs: &[Box<dyn Value>]) -> Box<dyn Value> {
@@ -431,7 +412,7 @@ pub fn text_replace(inputs: &[Box<dyn Value>]) -> Box<dyn Value> {
     }
 
     result.push_str(text.get(end..text.len()).unwrap());
-    Box::new(TextValue { value: result })
+    Box::new(TextValue::new(result))
 }
 
 pub fn text_substring(inputs: &[Box<dyn Value>]) -> Box<dyn Value> {
@@ -442,61 +423,49 @@ pub fn text_substring(inputs: &[Box<dyn Value>]) -> Box<dyn Value> {
     let length = inputs[2].as_int().unwrap();
 
     if start > text.len() || length > text.len() as i64 {
-        return Box::new(TextValue { value: text });
+        return Box::new(TextValue::new(text));
     }
     if length < 0 {
-        return Box::new(TextValue {
-            value: "".to_string(),
-        });
+        return Box::new(TextValue::empty());
     }
 
     // Convert it to Vec<Char> to be easy to substring with support of unicode
     let chars: Vec<char> = text.chars().collect();
     let slice = &chars[start..(start + length as usize)];
-    Box::new(TextValue {
-        value: slice.iter().collect(),
-    })
+    Box::new(TextValue::new(slice.iter().collect()))
 }
 
 pub fn text_stuff(inputs: &[Box<dyn Value>]) -> Box<dyn Value> {
     let text = inputs[0].as_text().unwrap();
     let start = (inputs[1].as_int().unwrap() - 1) as usize;
     let length = inputs[2].as_int().unwrap() as usize;
-    let new_string = inputs[3].as_text().unwrap();
 
-    if text.is_empty() {
-        return Box::new(TextValue { value: text });
-    }
-
-    if start > text.len() || length > text.len() {
-        return Box::new(TextValue { value: text });
+    if text.is_empty() || start > text.len() || length > text.len() {
+        return Box::new(TextValue::new(text));
     }
 
     let mut text = text.chars().collect::<Vec<_>>();
+    let new_string = inputs[3].as_text().unwrap();
     let new_string = new_string.chars().collect::<Vec<_>>();
     text.splice(start..(start + length), new_string);
-    Box::new(TextValue {
-        value: text.into_iter().collect(),
-    })
+    Box::new(TextValue::new(text.into_iter().collect()))
 }
 
 pub fn text_right(inputs: &[Box<dyn Value>]) -> Box<dyn Value> {
     let text = inputs[0].as_text().unwrap();
     if text.is_empty() {
-        return Box::new(TextValue {
-            value: "".to_string(),
-        });
+        return Box::new(TextValue::empty());
     }
 
     let number_of_chars = inputs[1].as_int().unwrap() as usize;
     if number_of_chars > text.len() {
-        return Box::new(TextValue { value: text });
+        return Box::new(TextValue::new(text));
     }
 
     let text = text.as_str();
-    Box::new(TextValue {
-        value: text[text.len() - number_of_chars..text.len()].to_string(),
-    })
+    Box::new(TextValue::new(
+        text[text.len() - number_of_chars..text.len()].to_string(),
+    ))
 }
 
 pub fn text_translate(inputs: &[Box<dyn Value>]) -> Box<dyn Value> {
@@ -505,9 +474,7 @@ pub fn text_translate(inputs: &[Box<dyn Value>]) -> Box<dyn Value> {
     let translations = inputs[2].as_text().unwrap();
 
     if translations.len() != characters.len() {
-        return Box::new(TextValue {
-            value: "".to_string(),
-        });
+        return Box::new(TextValue::empty());
     }
 
     let translations = translations.chars().collect::<Vec<_>>();
@@ -515,7 +482,7 @@ pub fn text_translate(inputs: &[Box<dyn Value>]) -> Box<dyn Value> {
         text = text.replace(letter, &char::to_string(&translations[idx]));
     }
 
-    Box::new(TextValue { value: text })
+    Box::new(TextValue::new(text))
 }
 
 pub fn text_unicode(inputs: &[Box<dyn Value>]) -> Box<dyn Value> {
@@ -524,20 +491,16 @@ pub fn text_unicode(inputs: &[Box<dyn Value>]) -> Box<dyn Value> {
     } else {
         0
     };
-
-    Box::new(IntValue { value })
+    Box::new(IntValue::new(value))
 }
 
 pub fn text_soundex(inputs: &[Box<dyn Value>]) -> Box<dyn Value> {
     let text = inputs[0].as_text().unwrap();
     if text.is_empty() {
-        return Box::new(TextValue {
-            value: "".to_string(),
-        });
+        return Box::new(TextValue::empty());
     }
 
     let mut result = String::from(text.chars().next().unwrap());
-
     for (idx, letter) in text.char_indices() {
         if idx != 0 {
             let letter = letter.to_ascii_uppercase();
@@ -554,7 +517,7 @@ pub fn text_soundex(inputs: &[Box<dyn Value>]) -> Box<dyn Value> {
                 result.push_str(&int.to_string());
 
                 if result.len() == 4 {
-                    return Box::new(TextValue { value: result });
+                    return Box::new(TextValue::new(result));
                 }
             }
         }
@@ -567,21 +530,19 @@ pub fn text_soundex(inputs: &[Box<dyn Value>]) -> Box<dyn Value> {
         }
     }
 
-    Box::new(TextValue { value: result })
+    Box::new(TextValue::new(result))
 }
 
 pub fn text_concat(inputs: &[Box<dyn Value>]) -> Box<dyn Value> {
     let text: Vec<String> = inputs.iter().map(|v| v.to_string()).collect();
-    Box::new(TextValue {
-        value: text.concat(),
-    })
+    Box::new(TextValue::new(text.concat()))
 }
 
 pub fn text_concat_ws(inputs: &[Box<dyn Value>]) -> Box<dyn Value> {
     let separator = inputs[0].as_text().unwrap();
     let text: Vec<String> = inputs.iter().skip(1).map(|v| v.to_string()).collect();
     let value = text.join(&separator);
-    Box::new(TextValue { value })
+    Box::new(TextValue::new(value))
 }
 
 pub fn text_strcmp(inputs: &[Box<dyn Value>]) -> Box<dyn Value> {
@@ -590,7 +551,7 @@ pub fn text_strcmp(inputs: &[Box<dyn Value>]) -> Box<dyn Value> {
         std::cmp::Ordering::Equal => 2,
         std::cmp::Ordering::Greater => 0,
     };
-    Box::new(IntValue { value })
+    Box::new(IntValue::new(value))
 }
 
 pub fn text_quotename(inputs: &[Box<dyn Value>]) -> Box<dyn Value> {
@@ -631,42 +592,38 @@ pub fn text_str(inputs: &[Box<dyn Value>]) -> Box<dyn Value> {
         let number_string = format!("{:.dec$}", int_value, dec = decimals as usize);
         if length > 0 {
             if (length as usize) < number_string.len() {
-                return Box::new(TextValue {
-                    value: number_string[..length as usize].to_owned(),
-                });
-            } else {
-                return Box::new(TextValue {
-                    value: format!("{:<len$}", number_string, len = length as usize),
-                });
+                return Box::new(TextValue::new(number_string[..length as usize].to_owned()));
             }
+
+            return Box::new(TextValue::new(format!(
+                "{:<len$}",
+                number_string,
+                len = length as usize
+            )));
         }
 
-        return Box::new(TextValue {
-            value: number_string.clone(),
-        });
+        return Box::new(TextValue::new(number_string.clone()));
     }
 
     let float_value = value.as_float().unwrap();
     let number_string = format!("{:.dec$}", float_value, dec = decimals as usize);
     if length > 0 {
         if (length as usize) < number_string.len() {
-            return Box::new(TextValue {
-                value: number_string[..length as usize].to_owned(),
-            });
-        } else {
-            return Box::new(TextValue {
-                value: format!("{:<len$}", number_string, len = length as usize),
-            });
+            return Box::new(TextValue::new(number_string[..length as usize].to_owned()));
         }
+
+        return Box::new(TextValue::new(format!(
+            "{:<len$}",
+            number_string,
+            len = length as usize
+        )));
     }
 
-    Box::new(TextValue {
-        value: number_string.clone(),
-    })
+    Box::new(TextValue::new(number_string.clone()))
 }
 
 pub fn text_to_hex(inputs: &[Box<dyn Value>]) -> Box<dyn Value> {
     let number = inputs[0].as_int().unwrap();
     let value = format!("0x{}", number);
-    Box::new(TextValue { value })
+    Box::new(TextValue::new(value))
 }
