@@ -8,13 +8,14 @@ use gitql::validate_git_repositories;
 use gitql_cli::arguments;
 use gitql_cli::arguments::Arguments;
 use gitql_cli::arguments::Command;
-use gitql_cli::arguments::OutputFormat;
 use gitql_cli::diagnostic_reporter;
 use gitql_cli::diagnostic_reporter::DiagnosticReporter;
-use gitql_cli::printer::base::OutputPrinter;
-use gitql_cli::printer::csv_printer::CSVPrinter;
-use gitql_cli::printer::json_printer::JSONPrinter;
-use gitql_cli::printer::table_printer::TablePrinter;
+use gitql_cli::printer::BaseOutputPrinter;
+use gitql_cli::printer::CSVPrinter;
+use gitql_cli::printer::JSONPrinter;
+use gitql_cli::printer::OutputFormatKind;
+use gitql_cli::printer::TablePrinter;
+use gitql_cli::printer::YAMLPrinter;
 use gitql_core::environment::Environment;
 use gitql_engine::data_provider::DataProvider;
 use gitql_engine::engine;
@@ -47,7 +48,7 @@ fn main() {
                     "",
                     Diagnostic::error(git_repos_result.err().unwrap().as_str()),
                 );
-                return;
+                std::process::exit(1);
             }
 
             let repos = git_repos_result.ok().unwrap();
@@ -64,7 +65,7 @@ fn main() {
                     &query,
                     Diagnostic::error(git_repos_result.err().unwrap().as_str()),
                 );
-                return;
+                std::process::exit(1);
             }
 
             let repos = git_repos_result.ok().unwrap();
@@ -93,7 +94,7 @@ fn launch_gitql_repl(arguments: &Arguments) {
             "",
             Diagnostic::error(git_repos_result.err().unwrap().as_str()),
         );
-        return;
+        std::process::exit(1);
     }
 
     let git_repositories = git_repos_result.ok().unwrap();
@@ -185,7 +186,7 @@ fn execute_gitql_query(
     if tokenizer_result.is_err() {
         let diagnostic = tokenizer_result.err().unwrap();
         reporter.report_diagnostic(&query, *diagnostic);
-        return;
+        std::process::exit(1);
     }
 
     let tokens = tokenizer_result.ok().unwrap();
@@ -197,7 +198,7 @@ fn execute_gitql_query(
     if parser_result.is_err() {
         let diagnostic = parser_result.err().unwrap();
         reporter.report_diagnostic(&query, *diagnostic);
-        return;
+        std::process::exit(1);
     }
 
     let query_node = parser_result.ok().unwrap();
@@ -212,15 +213,16 @@ fn execute_gitql_query(
     if evaluation_result.is_err() {
         let exception = Diagnostic::exception(&evaluation_result.err().unwrap());
         reporter.report_diagnostic("", exception);
-        return;
+        std::process::exit(1);
     }
 
-    let printer: Box<dyn OutputPrinter> = match arguments.output_format {
-        OutputFormat::Render => {
+    let printer: Box<dyn BaseOutputPrinter> = match arguments.output_format {
+        OutputFormatKind::Table => {
             Box::new(TablePrinter::new(arguments.pagination, arguments.page_size))
         }
-        OutputFormat::JSON => Box::new(JSONPrinter {}),
-        OutputFormat::CSV => Box::new(CSVPrinter {}),
+        OutputFormatKind::JSON => Box::new(JSONPrinter),
+        OutputFormatKind::CSV => Box::new(CSVPrinter),
+        OutputFormatKind::YAML => Box::new(YAMLPrinter),
     };
 
     // Render the result only if they are selected groups not any other statement
